@@ -498,11 +498,9 @@ class WorkerPool(object):
                 task.cancel()
 
     async def shutdown(self, exit_code=0):
+        print('Shutting down')
         await self.terminate_all()
-        await asyncio.sleep(0.5)
-
-        loop = asyncio.get_event_loop()
-        loop.call_soon_threadsafe(sys.exit, exit_code)
+        asyncio.get_event_loop().call_soon_threadsafe(sys.exit, exit_code)
 
     async def process_tasks(self):
         self.pbar.start(max_value=len(self.tasks))
@@ -519,7 +517,7 @@ class WorkerPool(object):
 
         loop = asyncio.get_event_loop()
 
-        loop.add_signal_handler(signal.SIGTERM, lambda: asyncio.create_task(self.shutdown(exit_code=1)))
+        loop.add_signal_handler(signal.SIGTERM, lambda: asyncio.ensure_future(self.shutdown(exit_code=1)))
 
         try:
             loop.run_until_complete(self.process_tasks())
